# Кодекс поведения участников Contributor Covenant

## Наше обещание

Мы, как участники, контрибьюторы и лидеры, обязуемся сделать участие в нашем сообществе свободным от преследований для всех, независимо от возраста, размера тела, видимых или невидимых ограничений возможностей, этнической принадлежности, половых характеристик, гендерной идентичности и самовыражения, уровня опыта, образования, социально-экономического статуса, национальности, внешнего вида, расы, религии или сексуальной идентичности и ориентации.

Мы обязуемся действовать и взаимодействовать таким образом, чтобы способствовать созданию открытого, дружелюбного, разнообразного, инклюзивного и здорового сообщества.

## Наши стандарты

Примеры поведения, способствующего созданию благоприятной среды для нашего сообщества, включают:

* Проявление эмпатии и доброты по отношению к другим людям  
* Уважение к различным мнениям, точкам зрения и опыту  
* Предоставление и достойное принятие конструктивной обратной связи  
* Принятие ответственности и извинение перед теми, кого затронули наши ошибки, а также извлечение уроков из этого опыта

* Фокусирование на том, что лучше не только для нас как отдельных личностей, но и для всего сообщества в целом.

Примеры неприемлемого поведения включают:

* Использование сексуализированного языка или образов, а также сексуальное внимание или домогательства любого рода

* Троллинг, оскорбительные или уничижительные комментарии, а также личные или политические нападки  
* Преследование, как публичное, так и частное  
* Разглашение личной информации других лиц, например физического или электронного адреса, без их явного разрешения

* Другое поведение, которое можно разумно считать неуместным в профессиональной обстановке

## Обязанности по обеспечению соблюдения

Лидеры сообщества несут ответственность за разъяснение и соблюдение наших стандартов приемлемого поведения и предпримут соответствующие и справедливые корректирующие действия в ответ на любое поведение, которое они сочтут неприемлемым, угрожающим, оскорбительным или вредным.

Лидеры сообщества имеют право и обязанность удалять, редактировать или отклонять комментарии, коммиты, код, правки вики, проблемы и другие вклады, которые не соответствуют данному Кодексу поведения, и будут сообщать причины решений о модерации, когда это уместно.

## Область применения

Этот Кодекс поведения применяется во всех сообществах, а также когда человек официально представляет сообщество в публичных пространствах.  
Примеры представления нашего сообщества включают использование официального адреса электронной почты, публикации через официальный аккаунт в социальных сетях или участие в качестве назначенного представителя на онлайн- или оффлайн-мероприятии.

## Принудительное применение

Случаи оскорбительного, преследующего или иного неприемлемого поведения могут быть сообщены лидерам сообщества, ответственным за соблюдение правил, по адресу aw@funstory.ai.  
Все жалобы будут рассмотрены и расследованы оперативно и справедливо.  

Все лидеры сообщества обязаны уважать конфиденциальность и безопасность лица, сообщившего о любом инциденте.

## Руководство по применению

Лидеры сообщества будут руководствоваться следующими принципами воздействия на сообщество при определении последствий для любых действий, которые они сочтут нарушающими данный Кодекс поведения:

### 1. Исправление

**Влияние на сообщество**: Использование неуместного языка или другое поведение, которое считается непрофессиональным или нежелательным в сообществе.

**Последствие**: Частное письменное предупреждение от лидеров сообщества с разъяснением характера нарушения и объяснением, почему поведение было неуместным. Может быть запрошено публичное извинение.

### 2. Предупреждение

**Влияние на сообщество**: Нарушение, произошедшее в результате одного инцидента или серии действий.

**Последствия**: Предупреждение с последствиями за повторное нарушение. Запрет на взаимодействие с вовлечёнными лицами, включая нежелательные контакты с теми, кто обеспечивает соблюдение Кодекса поведения, на определённый период времени. Это включает избегание взаимодействий как в пространствах сообщества, так и на внешних каналах, таких как социальные сети. Нарушение этих условий может привести к временному или постоянному бану.

### 3. Временный бан

**Влияние на сообщество**: Серьезное нарушение стандартов сообщества, включая постоянное недопустимое поведение.

**Последствие**: Временный запрет на любые виды взаимодействия или публичного общения с сообществом на определенный период времени. Никакое публичное или частное взаимодействие с вовлеченными лицами, включая нежелательное взаимодействие с теми, кто обеспечивает соблюдение Кодекса поведения, не допускается в течение этого периода. Нарушение этих условий может привести к постоянному запрету.

### 4. Постоянный бан

**Влияние на сообщество**: Демонстрация систематического нарушения стандартов сообщества, включая устойчивое неадекватное поведение, преследование отдельных лиц или агрессию в отношении групп людей или их дискредитацию.

**Последствие**: Постоянный запрет на любые формы публичного взаимодействия в рамках сообщества.

## Атрибуция

Этот Кодекс поведения адаптирован из [Contributor Covenant][homepage],  
версия 2.0, доступная по адресу  
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.  

Руководство по влиянию на сообщество вдохновлено [лестницей применения кодекса поведения Mozilla](https://github.com/mozilla/diversity).  

[homepage]: https://www.contributor-covenant.org  

Ответы на часто задаваемые вопросы о данном кодексе поведения можно найти в разделе [FAQ](#Часто-задаваемые-вопросы) по адресу  
https://www.contributor-covenant.org/faq. Переводы доступны на  
https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Часть содержимого этой страницы была переведена GPT и может содержать ошибки.</small></h6>